@@ -1,8 +1,11 @@
 //! **PostgreSQL** database driver.
 
+use crate::executor::Executor;
+
 mod arguments;
 mod column;
 mod connection;
+mod copy;
 mod database;
 mod error;
 mod io;
@@ -41,6 +44,10 @@ pub type PgPool = crate::pool::Pool<Postgres>;
 /// An alias for [`PoolOptions`][crate::pool::PoolOptions], specialized for Postgres.
 pub type PgPoolOptions = crate::pool::PoolOptions<Postgres>;
 
+/// An alias for [`Executor<'_, Database = Postgres>`][Executor].
+pub trait PgExecutor<'c>: Executor<'c, Database = Postgres> {}
+impl<'c, T: Executor<'c, Database = Postgres>> PgExecutor<'c> for T {}
+
 impl_into_arguments_for_arguments!(PgArguments);
 impl_executor_for_pool_connection!(Postgres, PgConnection, PgRow);
 impl_executor_for_transaction!(Postgres, PgRow);
